@@ -21,6 +21,22 @@ class Loader(yaml.Loader):
         self._root_base_ext = os.path.join(CFG_FILE_EXT, 'BASE')
         # This way for include relative on brand EXT dir
         self._root_brand_ext = os.path.join(CFG_FILE_EXT, brand)
+
+        # try to find out if source file is in a subfolder
+        if self._root_base in self._root_current:
+            suffix = self._root_current.replace(self._root_base, '')
+        elif self._root_base_ext in self._root_current:
+            suffix = self._root_current.replace(self._root_base_ext, '')
+        else:
+            suffix = self._root_current.replace(self._root_brand_ext, '')
+
+        # self.root_current_suffix will be empty if source file is in root
+        self.root_current_suffix = os.path.basename(suffix)
+        if self.root_current_suffix.upper() in cfg.STACK_TYPES:
+            # set to empty even if UPPERCASE subfolders is in cfg.STACK_TYPES
+            # so that they are not searched for include files
+            self.root_current_suffix = ''
+
         self.stream = stream
         super(Loader, self).__init__(stream)
         Loader.add_constructor('!include', Loader.include)
@@ -50,20 +66,17 @@ class Loader(yaml.Loader):
                 if filename in exclude_list + include_list:
                     continue
                 include_list.append(filename)
-                # if including Ext cfg
-                # try to include BASE file from CFG_FILE_INT too
-                if CFG_FILE_EXT in self.stream.name:
-                    result.append(
-                        self.extractFile(filename, self._root_base))
-                result.append(
-                    self.extractFile(filename, self._root_current))
-                # try to include BASE ext too
-                result.append(
-                    self.extractFile(filename, self._root_base_ext))
-                # try to include brand ext too
-                result.append(
-                    self.extractFile(filename, self._root_brand_ext))
-                # result += self.extractFile(filename)
+
+                # search for include in files in roots
+                for path in [self._root_base,
+                             self._root_base_ext,
+                             self._root_brand_ext]:
+                    result.append(self.extractFile(filename, path))
+                    if self.root_current_suffix:
+                        # search in subfolder too
+                        result.append(
+                            self.extractFile(filename, os.path.join(
+                                path, self.root_current_suffix)))
             return result
 
         elif isinstance(node, yaml.MappingNode):
@@ -229,8 +242,9 @@ def get_RP_for_envs(value):
     return RP
 
 
-def read_yaml(file_type, brand, base_dir):
-    cfg_file = os.path.join(base_dir, brand, f'{file_type}.yml')
+def read_yaml(file_type, brand, base_dir, stacktype=''):
+    cfg_file = os.path.join(
+        base_dir, brand, stacktype.upper(), f'{file_type}.yml')
 
     try:
         with open(cfg_file, 'r') as ymlfile:
@@ -294,7 +308,12 @@ def prepend_base_cfgs(cfg_cmm):
                         else:
                             # use IBOXBASE (or other value in cfg.BASE_CFGS)
                             for j, w in base_value.items():
-                                base_cfgs[n][j] = w
+                                j_current = base_cfgs[n].get(j)
+                                if j_current and isinstance(j_current, list):
+                                    # if property is a list extend it
+                                    base_cfgs[n][j].extend(w)
+                                else:
+                                    base_cfgs[n][j] = w
                             v.remove(k)
                     if not c[n]:
                         del c[n]
@@ -371,15 +390,6 @@ def get_RP_base_keys():
     return RP_base_keys + [stacktype, envrole]
 
 
-def get_stack_type(cfgs):
-    for c in cfgs:
-        try:
-            if isinstance(c[envrole], dict) and 'StackType' in c[envrole]:
-                return c[envrole]['StackType']
-        except KeyError:
-            pass
-
-
 def set_cfg():
     def RP_to_cfg(key):
         if hasattr(key, 'items'):
@@ -453,8 +463,6 @@ def set_cfg():
     if 'Internal' in cfg.RecordSet:
         cfg.RecordSetInternal = True
 
-    cfg.stacktype = stacktype
-
 
 def build_RP():
     global envrole
@@ -479,6 +487,7 @@ def build_RP():
     CFG_FILE_EXT = os.path.normpath(CFG_FILE_EXT)
 
     envrole = cfg.envrole
+    stacktype = cfg.stacktype
     brand = cfg.brand
 
     RP_base = {
@@ -496,19 +505,11 @@ def build_RP():
     cfg.RP_base = RP_base
 
     cfg_role = [
-        read_yaml(envrole, 'BASE', CFG_FILE_INT),
-        read_yaml(envrole, 'BASE', CFG_FILE_EXT),
-        read_yaml(envrole, brand, CFG_FILE_EXT),
+        read_yaml(envrole, 'BASE', CFG_FILE_INT, stacktype),
+        read_yaml(envrole, 'BASE', CFG_FILE_EXT, stacktype),
+        read_yaml(envrole, brand, CFG_FILE_EXT, stacktype),
     ]
 
-    stacktype = get_stack_type(cfg_role)
-
-    if not stacktype:
-        logging.error(
-            f'StackType key not found for Role {envrole} '
-            f'in paths: {CFG_FILE_EXT}, {CFG_FILE_INT}')
-        exit(1)
-
     cfgs = {
         'common': [
             read_yaml('common', 'BASE', CFG_FILE_INT),
@@ -516,9 +517,9 @@ def build_RP():
             read_yaml('common', brand, CFG_FILE_EXT),
         ],
         'type': [
-            read_yaml(stacktype, 'BASE', CFG_FILE_INT),
-            read_yaml(stacktype, 'BASE', CFG_FILE_EXT),
-            read_yaml(stacktype, brand, CFG_FILE_EXT),
+            read_yaml('TYPE', 'BASE', CFG_FILE_INT, stacktype),
+            read_yaml('TYPE', 'BASE', CFG_FILE_EXT, stacktype),
+            read_yaml('TYPE', brand, CFG_FILE_EXT, stacktype),
         ],
         'role': cfg_role,
     }
@@ -543,12 +544,6 @@ def build_RP():
         pprint(include_list)
         print('##########INCLUDED#######END#######')
 
-    try:
-        stacktype = RP['cmm']['cmm']['StackType']
-    except KeyError:
-        print('StackType key not found!')
-        exit(1)
-
     cfg.RP = RP
     cfg.RP_cmm = RP['cmm']['cmm']
 
