@@ -1,6 +1,10 @@
 import os
+import sys
 from functools import reduce
 
+cwd = os.getcwd()
+sys.path.append(os.path.join(cwd, 'lib'))
+
 no_override = False
 
 Parameters = {}
@@ -12,9 +16,22 @@ Outputs = {}
 PATH_INT = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'cfg')
 PATH_INT = os.path.normpath(PATH_INT)
 
-PATH_EXT = os.path.join(os.getcwd(), 'cfg')
+PATH_EXT = os.path.join(cwd, 'cfg')
 PATH_EXT = os.path.normpath(PATH_EXT)
 
+STACK_TYPES = [
+    'agw',
+    'alb',
+    'cch',
+    'clf',
+    'ec2',
+    'ecr',
+    'ecs',
+    'rds',
+    'res',
+    'tsk',
+]
+
 MAX_SECURITY_GROUPS = 4
 # SECURITY_GROUPS_DEFAULT equals list of empty values
 # (Ex. for "MAX_SECURITY_GROUPS = 3" we have "SECURITY_GROUPS_DEFAULT = ',,'")
@@ -66,6 +83,7 @@ EVAL_FUNCTIONS_IN_CFG = (
     'GetAtt(',
     'Split(',
     'Export(',
+    'ImportValue(',
     'Join(',
     'If(',
     'Equals(',
@@ -166,6 +184,13 @@ INSTANCE_LIST = [
     't4g.xlarge', 't4g.2xlarge',
 ]
 
+# override previous cfg with an External one
+try:
+    with open(os.path.join(cwd, 'lib', 'cfgExt.py')) as f:
+        exec(f.read())
+except FileNotFoundError:
+    pass
+
 # Order is VERY important do not CHANGE it!
 CFG_TO_FUNC = {
     'MappingClass': {'module': 'mappings',
@@ -216,6 +241,8 @@ CFG_TO_FUNC = {
                        'func': 'ECS_TaskDefinition'},
     'EFSFileSystem': {'module': 'efs',
                       'func': 'EFS_FileStorage'},
+    'EFSAccessPoint': {'module': 'efs',
+                       'func': 'EFS_AccessPoint'},
     'CacheSubnetGroup': {'module': 'elasticache',
                          'func': 'CCH_SubnetGroups'},
     'CacheCluster': {'module': 'elasticache',
@@ -296,6 +323,8 @@ CFG_TO_FUNC = {
             'func': 'VPC_VPC'},
     'CCRLightHouse': {'module': 'cloudformation',
                       'func': 'CFM_CustomResourceLightHouse'},
+    'CCRFargateSpot': {'module': 'cloudformation',
+                       'func': 'CFM_CustomResourceFargateSpot'},
     # ReplicateRegions need to stay here
     'CCRReplicateRegions': {'module': 'cloudformation',
                             'func': 'CFM_CustomResourceReplicator'},
