@@ -1,8 +1,8 @@
 import troposphere.codedeploy as cdd
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj)
 
 
 class CDEc2TagFilters(cdd.Ec2TagFilters):
