@@ -1,8 +1,8 @@
 import troposphere.events as eve
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj)
 from .lambdas import LambdaPermissionEvent
 from .securitygroup import SG_SecurityGroupsTSK
 
