@@ -1,8 +1,8 @@
 import troposphere.s3 as s3
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj, get_dictvalue)
 from .iam import (IAMRoleBucketReplica, IAMPolicyBucketReplica,
                   IAMPolicyStatement)
 from .cloudfront import CFOriginAccessIdentity
@@ -403,28 +403,32 @@ def S3_Buckets(key):
             key=v['Replication']['ConfigurationRules'])
 
         try:
-            lambda_arn = eval(
-                v['NotificationConfiguration']['LambdaConfigurations']
-                ['Trigger']['Function']
-            )
+            lbd_confs = v['NotificationConfiguration']['LambdaConfigurations']
         except Exception:
             pass
         else:
-            if 'Fn::GettAtt' in lambda_arn.data:
-                permname = '%s%s' % (
-                    lambda_arn.data['Fn::GettAtt'].replace(
-                        'Lambda', 'LambdaPermission'),
-                    resname)
-            else:
-                permname = 'LambdaPermission'
+            for lbd_n, lbd_v in lbd_confs.items():
+                lambda_arn = eval(lbd_v['Function'])
+                if 'Fn::GettAtt' in lambda_arn.data:
+                    permname = '%s%s' % (
+                        lambda_arn.data['Fn::GettAtt'].replace(
+                            'Lambda', 'LambdaPermission'),
+                        resname)
+                else:
+                    permname = 'LambdaPermission'
 
-            r_LambdaPermission = LambdaPermissionS3(
-                permname, key=lambda_arn, source=resname)
+                r_LambdaPermission = LambdaPermissionS3(
+                    permname, key=lambda_arn, source=resname)
 
-            add_obj(r_LambdaPermission)
+                add_obj(r_LambdaPermission)
 
-            BucketPolicyStatement.extend(
-                S3BucketPolicyStatementSes(resname))
+        try:
+            bucket_policies = getattr(cfg, 'BucketPolicy')
+        except Exception:
+            pass
+        else:
+            for policy_name, policy_value in bucket_policies.items():
+                BucketPolicyStatement.append(get_dictvalue(policy_value))
 
         if 'WebsiteConfiguration' in v:
             r_Bucket.WebsiteConfiguration = s3.WebsiteConfiguration(
