@@ -1,8 +1,8 @@
 import troposphere.sns as sns
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj)
 from .lambdas import LambdaPermissionSNS
 from .sqs import SQSQueuePolicy
 
@@ -32,7 +32,7 @@ def SNS_Topics(key):
         add_obj(r_Topic)
 
         # outputs
-        if 'Export' in v:
+        if v.get('Export'):
             o_Topic = Output(resname)
             o_Topic.Value = Ref(resname)
             o_Topic.Export = Export(resname)
