@@ -2,8 +2,8 @@ import troposphere.waf as waf
 import troposphere.wafregional as wafr
 
 from .common import *
-from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
-                     get_subvalue, auto_get_props, get_condition, add_obj)
+from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
+                     auto_get_props, get_condition, add_obj)
 
 
 class WAFIPSet(waf.IPSet):
